@@ -13,7 +13,7 @@ extern "C" {
 
 
 /** Defines the Baresip version string */
-#define BARESIP_VERSION "0.6.0"
+#define BARESIP_VERSION "0.6.1"
 
 
 #ifndef NET_MAX_NS
@@ -58,9 +58,13 @@ int account_set_auth_user(struct account *acc, const char *user);
 int account_set_auth_pass(struct account *acc, const char *pass);
 int account_set_outbound(struct account *acc, const char *ob, unsigned ix);
 int account_set_sipnat(struct account *acc, const char *sipnat);
+int account_set_answermode(struct account *acc, enum answermode mode);
 int account_set_display_name(struct account *acc, const char *dname);
 int account_set_regint(struct account *acc, uint32_t regint);
+int account_set_stun_host(struct account *acc, const char *host);
+int account_set_stun_port(struct account *acc, uint16_t port);
 int account_set_mediaenc(struct account *acc, const char *mediaenc);
+int account_set_medianat(struct account *acc, const char *medianat);
 int account_set_audio_codecs(struct account *acc, const char *codecs);
 int account_set_mwi(struct account *acc, const char *value);
 int account_set_call_transfer(struct account *acc, const char *value);
@@ -82,7 +86,9 @@ const char *account_sipnat(const struct account *acc);
 const char *account_stun_user(const struct account *acc);
 const char *account_stun_pass(const struct account *acc);
 const char *account_stun_host(const struct account *acc);
+uint16_t account_stun_port(const struct account *acc);
 const char *account_mediaenc(const struct account *acc);
+const char *account_medianat(const struct account *acc);
 const char *account_mwi(const struct account *acc);
 const char *account_call_transfer(const struct account *acc);
 
@@ -114,12 +120,6 @@ enum call_event {
 	CALL_EVENT_MENC,
 };
 
-enum menc_event {
-	MENC_EVENT_SECURE,
-	MENC_EVENT_VERIFY_REQUEST,
-	MENC_EVENT_PEER_VERIFIED,
-};
-
 struct call;
 
 typedef void (call_event_h)(struct call *call, enum call_event ev,
@@ -270,7 +270,6 @@ struct config_avt {
 	uint8_t rtp_tos;        /**< Type-of-Service for outg. RTP  */
 	struct range rtp_ports; /**< RTP port range                 */
 	struct range rtp_bw;    /**< RTP Bandwidth range [bit/s]    */
-	bool rtcp_enable;       /**< RTCP is enabled                */
 	bool rtcp_mux;          /**< RTP/RTCP multiplexing          */
 	struct range jbuf_del;  /**< Delay, number of frames        */
 	bool rtp_stats;         /**< Enable RTP statistics          */
@@ -350,6 +349,7 @@ int  contact_init(struct contacts **contactsp);
 int  contact_add(struct contacts *contacts,
 		 struct contact **contactp, const struct pl *addr);
 void contact_remove(struct contacts *contacts, struct contact *c);
+void contacts_enable_presence(struct contacts *contacts, bool enabled);
 void contact_set_update_handler(struct contacts *contacs,
 				contact_update_h *updateh, void *arg);
 int  contact_print(struct re_printf *pf, const struct contact *cnt);
@@ -364,6 +364,9 @@ struct list     *contact_list(const struct contacts *contacts);
 const char      *contact_str(const struct contact *c);
 const char      *contact_uri(const struct contact *c);
 const char      *contact_presence_str(enum presence_status status);
+struct le       *contact_le(struct contact *cnt);
+void contacts_set_current(struct contacts *contacts, struct contact *cnt);
+struct contact *contacts_current(const struct contacts *contacts);
 
 
 /*
@@ -380,8 +383,6 @@ struct media_ctx {
  * Media Device
  */
 
-struct mediadev;
-
 /** Defines a media device */
 struct mediadev {
 	struct le   le;
@@ -451,6 +452,7 @@ int ausrc_alloc(struct ausrc_st **stp, struct list *ausrcl,
 		const char *name,
 		struct ausrc_prm *prm, const char *device,
 		ausrc_read_h *rh, ausrc_error_h *errh, void *arg);
+struct ausrc *ausrc_get(struct ausrc_st *st);
 
 
 /*
@@ -489,6 +491,7 @@ int auplay_alloc(struct auplay_st **stp, struct list *auplayl,
 		 const char *name,
 		 struct auplay_prm *prm, const char *device,
 		 auplay_write_h *wh, void *arg);
+struct auplay *auplay_get(struct auplay_st *st);
 
 
 /*
@@ -580,6 +583,13 @@ struct menc;
 struct menc_sess;
 struct menc_media;
 
+/** Defines a media encryption event */
+enum menc_event {
+	MENC_EVENT_SECURE,          /**< Media is secured               */
+	MENC_EVENT_VERIFY_REQUEST,  /**< Request user to verify a code  */
+	MENC_EVENT_PEER_VERIFIED,   /**< Peer was verified successfully */
+};
+
 
 typedef void (menc_error_h)(int err, void *arg);
 
@@ -605,6 +615,7 @@ struct menc {
 void menc_register(struct list *mencl, struct menc *menc);
 void menc_unregister(struct menc *menc);
 const struct menc *menc_find(const struct list *mencl, const char *id);
+const char *menc_event_name(enum menc_event event);
 
 
 /*
@@ -727,7 +738,7 @@ void ua_set_catchall(struct ua *ua, bool enabled);
 void ua_event(struct ua *ua, enum ua_event ev, struct call *call,
 	      const char *fmt, ...);
 int ua_add_xhdr_filter(struct ua *ua, const char *hdr_name);
-void ua_set_custom_hdrs(struct ua *ua, struct list *custom_hdrs);
+int  ua_set_custom_hdrs(struct ua *ua, struct list *custom_hdrs);
 int  ua_uri_complete(struct ua *ua, struct mbuf *buf, const char *uri);
 int  ua_call_alloc(struct call **callp, struct ua *ua,
 		   enum vidmode vidmode, const struct sip_msg *msg,
@@ -803,9 +814,6 @@ int  ui_password_prompt(char **passwordp);
 /** Command flags */
 enum {
 	CMD_PRM  = (1<<0),              /**< Command with parameter */
-	CMD_PROG = (1<<1),              /**< Show progress          */
-
-	CMD_IPRM = CMD_PRM | CMD_PROG,  /**< Interactive parameter  */
 };
 
 /** Command arguments */
@@ -1109,7 +1117,20 @@ int vidfilt_dec_append(struct list *filtl, void **ctx,
  */
 
 struct audio;
+struct stream_param;
+struct mnat;
+struct mnat_sess;
 
+typedef void (audio_event_h)(int key, bool end, void *arg);
+typedef void (audio_err_h)(int err, const char *str, void *arg);
+
+int audio_alloc(struct audio **ap, const struct stream_param *stream_prm,
+		const struct config *cfg,
+		struct call *call, struct sdp_session *sdp_sess, int label,
+		const struct mnat *mnat, struct mnat_sess *mnat_sess,
+		const struct menc *menc, struct menc_sess *menc_sess,
+		uint32_t ptime, const struct list *aucodecl, bool offerer,
+		audio_event_h *eventh, audio_err_h *errh, void *arg);
 void audio_mute(struct audio *a, bool muted);
 bool audio_ismuted(const struct audio *a);
 void audio_set_devicename(struct audio *a, const char *src, const char *play);
@@ -1125,6 +1146,11 @@ int  audio_start(struct audio *a);
 void audio_stop(struct audio *a);
 bool audio_started(const struct audio *a);
 void audio_set_hold(struct audio *au, bool hold);
+int  audio_encoder_set(struct audio *a, const struct aucodec *ac,
+		       int pt_tx, const char *params);
+int  audio_decoder_set(struct audio *a, const struct aucodec *ac,
+		       int pt_rx, const char *params);
+const struct aucodec *audio_codec(const struct audio *au, bool tx);
 
 
 /*
@@ -1153,9 +1179,16 @@ uint64_t video_calc_timebase_timestamp(uint64_t rtp_ts);
  * Generic stream
  */
 
+/** Common parameters for media stream */
+struct stream_param {
+	bool use_rtp;
+	int af;
+	const char *cname;
+};
+void stream_update(struct stream *s);
 const struct rtcp_stats *stream_rtcp_stats(const struct stream *strm);
 struct call *stream_call(const struct stream *strm);
-const struct sdp_media *stream_sdp(const struct stream *strm);
+struct sdp_media *stream_sdpmedia(const struct stream *s);
 uint32_t stream_metric_get_tx_n_packets(const struct stream *strm);
 uint32_t stream_metric_get_tx_n_bytes(const struct stream *strm);
 uint32_t stream_metric_get_tx_n_err(const struct stream *strm);
@@ -1163,6 +1196,7 @@ uint32_t stream_metric_get_rx_n_packets(const struct stream *strm);
 uint32_t stream_metric_get_rx_n_bytes(const struct stream *strm);
 uint32_t stream_metric_get_rx_n_err(const struct stream *strm);
 
+
 /*
  * Media NAT
  */
@@ -1192,12 +1226,6 @@ int mnat_register(struct mnat **mnatp, struct list *mnatl,
 		  mnat_update_h *updateh);
 
 
-/*
- * Real-time
- */
-int realtime_enable(bool enable, int fps);
-
-
 /*
  * SDP
  */
@@ -1306,9 +1334,10 @@ static inline bool h264_is_keyframe(int type)
 #endif
 
 
-int module_preload(const char *module);
+int  module_preload(const char *module);
 int  module_load(const char *name);
 void module_unload(const char *name);
+void module_app_unload(void);
 
 
 /*
