@@ -13,13 +13,13 @@ static void auplay_destructor(void *arg)
 {
 	struct auplay_st *st = arg;
 
-	device_stop(st->dev);
+	aubridge_device_stop(st->dev);
 
 	mem_deref(st->dev);
 }
 
 
-int play_alloc(struct auplay_st **stp, const struct auplay *ap,
+int aubridge_play_alloc(struct auplay_st **stp, const struct auplay *ap,
 	       struct auplay_prm *prm, const char *device,
 	       auplay_write_h *wh, void *arg)
 {
@@ -44,7 +44,7 @@ int play_alloc(struct auplay_st **stp, const struct auplay *ap,
 	st->wh  = wh;
 	st->arg = arg;
 
-	err = device_connect(&st->dev, device, st, NULL);
+	err = aubridge_device_connect(&st->dev, device, st, NULL);
 	if (err)
 		goto out;
 
