@@ -102,7 +102,7 @@ static int new_session(struct call *call)
 
 	sess->call_in = call;
 	err = ua_connect(ua_out, &sess->call_out, call_peeruri(call),
-			 call_localuri(call), NULL,
+			 call_localuri(call),
 			 call_has_video(call) ? VIDMODE_ON : VIDMODE_OFF);
 	if (err) {
 		warning("b2bua: ua_connect failed (%m)\n", err);
