@@ -16,6 +16,8 @@ int coreaudio_recorder_alloc(struct ausrc_st **stp, const struct ausrc *as,
 			     struct media_ctx **ctx,
 			     struct ausrc_prm *prm, const char *device,
 			     ausrc_read_h *rh, ausrc_error_h *errh, void *arg);
-
-
-CFStringRef coreaudio_get_device_uid(const char *name);
+int coreaudio_enum_devices(const char *name, struct list *dev_list,
+			    CFStringRef *uid, Boolean is_input);
+uint32_t coreaudio_aufmt_to_formatflags(enum aufmt fmt);
+int coreaudio_player_init(struct auplay *ap);
+int coreaudio_recorder_init(struct ausrc *as);
