@@ -24,6 +24,7 @@ struct auplay_st {
 	AudioQueueRef queue;
 	AudioQueueBufferRef buf[BUFC];
 	pthread_mutex_t mutex;
+	uint32_t sampsz;
 	auplay_write_h *wh;
 	void *arg;
 };
@@ -70,7 +71,7 @@ static void play_handler(void *userData, AudioQueueRef outQ,
 	if (!wh)
 		return;
 
-	wh(outQB->mAudioData, outQB->mAudioDataByteSize/2, arg);
+	wh(outQB->mAudioData, outQB->mAudioDataByteSize/st->sampsz, arg);
 
 	AudioQueueEnqueueBuffer(outQ, outQB, 0, NULL);
 }
@@ -86,7 +87,7 @@ int coreaudio_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 	OSStatus status;
 	int err;
 
-	if (!stp || !ap || !prm || prm->fmt != AUFMT_S16LE)
+	if (!stp || !ap || !prm)
 		return EINVAL;
 
 	st = mem_zalloc(sizeof(*st), auplay_destructor);
@@ -97,6 +98,12 @@ int coreaudio_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 	st->wh  = wh;
 	st->arg = arg;
 
+	st->sampsz = (uint32_t)aufmt_sample_size(prm->fmt);
+	if (!st->sampsz) {
+		err = ENOTSUP;
+		goto out;
+	}
+
 	err = pthread_mutex_init(&st->mutex, NULL);
 	if (err)
 		goto out;
@@ -107,16 +114,16 @@ int coreaudio_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 
 	fmt.mSampleRate       = (Float64)prm->srate;
 	fmt.mFormatID         = kAudioFormatLinearPCM;
-	fmt.mFormatFlags      = kLinearPCMFormatFlagIsSignedInteger |
+	fmt.mFormatFlags      = coreaudio_aufmt_to_formatflags(prm->fmt) |
 		                kAudioFormatFlagIsPacked;
 #ifdef __BIG_ENDIAN__
 	fmt.mFormatFlags     |= kAudioFormatFlagIsBigEndian;
 #endif
 	fmt.mFramesPerPacket  = 1;
-	fmt.mBytesPerFrame    = prm->ch * 2;
-	fmt.mBytesPerPacket   = prm->ch * 2;
+	fmt.mBytesPerFrame    = prm->ch * st->sampsz;
+	fmt.mBytesPerPacket   = prm->ch * st->sampsz;
 	fmt.mChannelsPerFrame = prm->ch;
-	fmt.mBitsPerChannel   = 16;
+	fmt.mBitsPerChannel   = 8 * st->sampsz;
 
 	status = AudioQueueNewOutput(&fmt, play_handler, st, NULL,
 				     kCFRunLoopCommonModes, 0, &st->queue);
@@ -132,7 +139,10 @@ int coreaudio_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 
 		info("coreaudio: player: using device '%s'\n", device);
 
-		uid = coreaudio_get_device_uid(device);
+		err = coreaudio_enum_devices(device, NULL, &uid, false);
+		if (err)
+			goto out;
+
 		if (!uid) {
 			warning("coreaudio: player: device not found: '%s'\n",
 				device);
@@ -154,7 +164,7 @@ int coreaudio_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 	}
 
 	sampc = prm->srate * prm->ch * prm->ptime / 1000;
-	bytc  = sampc * 2;
+	bytc  = sampc * st->sampsz;
 
 	for (i=0; i<ARRAY_SIZE(st->buf); i++)  {
 
@@ -188,3 +198,14 @@ int coreaudio_player_alloc(struct auplay_st **stp, const struct auplay *ap,
 
 	return err;
 }
+
+
+int coreaudio_player_init(struct auplay *ap)
+{
+	if (!ap)
+		return EINVAL;
+
+	list_init(&ap->dev_list);
+
+	return coreaudio_enum_devices(NULL, &ap->dev_list, NULL, false);
+}
