@@ -22,8 +22,6 @@
  *
  \verbatim
   <sip:user@domain.com>;mediaenc=dtls_srtp
-  <sip:user@domain.com>;mediaenc=dtls_srtpf
-  <sip:user@domain.com>;mediaenc=srtp-mandf
  \endverbatim
  *
  *
@@ -117,11 +115,7 @@ static bool verify_fingerprint(const struct sdp_session *sess,
 				   &hash, md_sdp, &sz_sdp))
 		return false;
 
-	if (0 == pl_strcasecmp(&hash, "sha-1")) {
-		type = TLS_FINGERPRINT_SHA1;
-		sz_dtls = 20;
-	}
-	else if (0 == pl_strcasecmp(&hash, "sha-256")) {
+	if (0 == pl_strcasecmp(&hash, "sha-256")) {
 		type = TLS_FINGERPRINT_SHA256;
 		sz_dtls = 32;
 	}
@@ -426,13 +420,7 @@ static int media_alloc(struct menc_media **mp, struct menc_sess *sess,
 		if (err)
 			return err;
 
-		if (0 == pl_strcasecmp(&hash, "SHA-1")) {
-			err = sdp_media_set_lattr(st->sdpm, true,
-						  "fingerprint", "SHA-1 %H",
-						  dtls_print_sha1_fingerprint,
-						  tls);
-		}
-		else if (0 == pl_strcasecmp(&hash, "SHA-256")) {
+		if (0 == pl_strcasecmp(&hash, "SHA-256")) {
 			err = sdp_media_set_lattr(st->sdpm, true,
 						  "fingerprint", "SHA-256 %H",
 						 dtls_print_sha256_fingerprint,
@@ -450,16 +438,7 @@ static int media_alloc(struct menc_media **mp, struct menc_sess *sess,
 
 
 static struct menc dtls_srtp = {
-	LE_INIT, "dtls_srtp",  "UDP/TLS/RTP/SAVP", session_alloc, media_alloc
-};
-
-static struct menc dtls_srtpf = {
-	LE_INIT, "dtls_srtpf", "UDP/TLS/RTP/SAVPF", session_alloc, media_alloc
-};
-
-static struct menc dtls_srtp2 = {
-	/* note: temp for Webrtc interop */
-	LE_INIT, "srtp-mandf", "RTP/SAVPF", session_alloc, media_alloc
+	LE_INIT, "dtls_srtp",  "UDP/TLS/RTP/SAVPF", session_alloc, media_alloc
 };
 
 
@@ -491,9 +470,7 @@ static int module_init(void)
 		return err;
 	}
 
-	menc_register(mencl, &dtls_srtpf);
 	menc_register(mencl, &dtls_srtp);
-	menc_register(mencl, &dtls_srtp2);
 
 	debug("DTLS-SRTP ready with profiles %s\n", srtp_profiles);
 
@@ -504,8 +481,6 @@ static int module_init(void)
 static int module_close(void)
 {
 	menc_unregister(&dtls_srtp);
-	menc_unregister(&dtls_srtpf);
-	menc_unregister(&dtls_srtp2);
 	tls = mem_deref(tls);
 
 	return 0;
