@@ -333,28 +333,11 @@ static int create_ua(struct re_printf *pf, void *arg)
 
 	if (str_isset(carg->prm)) {
 
-		mbuf_rewind(menu.dialbuf);
-		(void)mbuf_write_str(menu.dialbuf, carg->prm);
-
 		(void)re_hprintf(pf, "Creating UA for %s ...\n", carg->prm);
 		err = ua_alloc(&ua, carg->prm);
 		if (err)
 			goto out;
 	}
-	else if (menu.dialbuf->end > 0) {
-
-		char *uri;
-
-		menu.dialbuf->pos = 0;
-		err = mbuf_strdup(menu.dialbuf, &uri, menu.dialbuf->end);
-		if (err)
-			return err;
-
-		(void)re_hprintf(pf, "Creating UA for %s ...\n", uri);
-		err |=  ua_alloc(&ua, uri);
-
-		mem_deref(uri);
-	}
 
 	if (account_regint(ua_account(ua))) {
 		(void)ua_register(ua);
@@ -403,6 +386,30 @@ static int cmd_ua_next(struct re_printf *pf, void *unused)
 }
 
 
+static int cmd_ua_find(struct re_printf *pf, void *arg)
+{
+	const struct cmd_arg *carg = arg;
+	struct ua *ua = NULL;
+
+	if (str_isset(carg->prm)) {
+		ua = uag_find_aor(carg->prm);
+	}
+
+	if (!ua) {
+		warning("menu: ua_find failed: %s\n", carg->prm);
+		return ENOENT;
+	}
+
+	re_hprintf(pf, "ua: %s\n", ua_aor(ua));
+
+	uag_current_set(ua);
+
+	update_callstatus();
+
+	return 0;
+}
+
+
 static int print_commands(struct re_printf *pf, void *unused)
 {
 	(void)unused;
@@ -456,11 +463,12 @@ static const struct cmd cmdv[] = {
 {NULL,        KEYCODE_ESC,0, "Hangup call",             cmd_hangup           },
 {"uanext",    'T',        0, "Toggle UAs",              cmd_ua_next          },
 {"uanew",     0,    CMD_PRM, "Create User-Agent",       create_ua            },
-{"ausrc",     0,   CMD_IPRM, "Switch audio source",     switch_audio_source  },
-{"auplay",    0,   CMD_IPRM, "Switch audio player",     switch_audio_player  },
+{"uafind",    0,    CMD_PRM, "Find User-Agent <aor>",   cmd_ua_find          },
+{"ausrc",     0,    CMD_PRM, "Switch audio source",     switch_audio_source  },
+{"auplay",    0,    CMD_PRM, "Switch audio player",     switch_audio_player  },
 {"about",     0,          0, "About box",               about_box            },
 #ifdef USE_VIDEO
-{"vidsrc",    0,   CMD_IPRM, "Switch video source",     switch_video_source  },
+{"vidsrc",    0,    CMD_PRM, "Switch video source",     switch_video_source  },
 #endif
 
 };
@@ -522,22 +530,9 @@ static int call_mute(struct re_printf *pf, void *unused)
 static int call_xfer(struct re_printf *pf, void *arg)
 {
 	const struct cmd_arg *carg = arg;
-	static bool xfer_inprogress;
+	(void)pf;
 
-	if (!xfer_inprogress && !carg->complete) {
-		menu.statmode = STATMODE_OFF;
-		re_hprintf(pf, "\rPlease enter transfer target SIP uri:\n");
-	}
-
-	xfer_inprogress = true;
-
-	if (carg->complete) {
-		menu.statmode = STATMODE_CALL;
-		xfer_inprogress = false;
-		return call_transfer(ua_call(uag_cur()), carg->prm);
-	}
-
-	return 0;
+	return call_transfer(ua_call(uag_cur()), carg->prm);
 }
 
 
@@ -580,75 +575,61 @@ static int switch_audio_player(struct re_printf *pf, void *arg)
 	char driver[16], device[128] = "";
 	int err = 0;
 
-	static bool switch_aud_inprogress;
+	if (re_regex(carg->prm, str_len(carg->prm), "[^,]+,[~]*",
+		     &pl_driver, &pl_device)) {
 
-	if (!switch_aud_inprogress && !carg->complete) {
-		re_hprintf(pf,
-			   "\rPlease enter audio device (driver,device)\n");
+		return re_hprintf(pf, "\rFormat should be:"
+				  " driver,device\n");
 	}
 
-	switch_aud_inprogress = true;
+	pl_strcpy(&pl_driver, driver, sizeof(driver));
+	pl_strcpy(&pl_device, device, sizeof(device));
 
-	if (carg->complete) {
+	ap = auplay_find(baresip_auplayl(), driver);
+	if (!ap) {
+		re_hprintf(pf, "no such audio-player: %s\n", driver);
+		return 0;
+	}
+	else if (!list_isempty(&ap->dev_list)) {
 
-		switch_aud_inprogress = false;
+		if (!mediadev_find(&ap->dev_list, device)) {
+			re_hprintf(pf,
+				   "no such device for %s audio-player: %s\n",
+				   driver, device);
 
-		if (re_regex(carg->prm, str_len(carg->prm), "[^,]+,[~]*",
-			     &pl_driver, &pl_device)) {
+			mediadev_print(pf, &ap->dev_list);
 
-			return re_hprintf(pf, "\rFormat should be:"
-					  " driver,device\n");
-		}
-
-		pl_strcpy(&pl_driver, driver, sizeof(driver));
-		pl_strcpy(&pl_device, device, sizeof(device));
-
-		ap = auplay_find(baresip_auplayl(), driver);
-		if (!ap) {
-			re_hprintf(pf, "no such audio-player: %s\n", driver);
 			return 0;
 		}
-		else if (!list_isempty(&ap->dev_list)) {
+	}
 
-			if (!mediadev_find(&ap->dev_list, device)) {
-				re_hprintf(pf,
-				  "no such device for %s audio-player: %s\n",
-				  driver, device);
+	re_hprintf(pf, "switch audio player: %s,%s\n",
+		   driver, device);
 
-				mediadev_print(pf, &ap->dev_list);
+	cfg = conf_config();
+	if (!cfg) {
+		return re_hprintf(pf, "no config object\n");
+	}
 
-				return 0;
-			}
-		}
+	aucfg = &cfg->audio;
 
-		re_hprintf(pf, "switch audio player: %s,%s\n",
-			   driver, device);
+	str_ncpy(aucfg->play_mod, driver, sizeof(aucfg->play_mod));
+	str_ncpy(aucfg->play_dev, device, sizeof(aucfg->play_dev));
 
-		cfg = conf_config();
-		if (!cfg) {
-			return re_hprintf(pf, "no config object\n");
-		}
+	str_ncpy(aucfg->alert_mod, driver, sizeof(aucfg->alert_mod));
+	str_ncpy(aucfg->alert_dev, device, sizeof(aucfg->alert_dev));
 
-		aucfg = &cfg->audio;
+	for (le = list_tail(ua_calls(uag_cur())); le; le = le->prev) {
 
-		str_ncpy(aucfg->play_mod, driver, sizeof(aucfg->play_mod));
-		str_ncpy(aucfg->play_dev, device, sizeof(aucfg->play_dev));
+		struct call *call = le->data;
 
-		str_ncpy(aucfg->alert_mod, driver, sizeof(aucfg->alert_mod));
-		str_ncpy(aucfg->alert_dev, device, sizeof(aucfg->alert_dev));
+		a = call_audio(call);
 
-		for (le = list_tail(ua_calls(uag_cur())); le; le = le->prev) {
-
-			struct call *call = le->data;
-
-			a = call_audio(call);
-
-			err = audio_set_player(a, driver, device);
-			if (err) {
-				re_hprintf(pf, "failed to set audio-player"
-					   " (%m)\n", err);
-				break;
-			}
+		err = audio_set_player(a, driver, device);
+		if (err) {
+			re_hprintf(pf, "failed to set audio-player"
+				   " (%m)\n", err);
+			break;
 		}
 	}
 
@@ -668,72 +649,58 @@ static int switch_audio_source(struct re_printf *pf, void *arg)
 	char driver[16], device[128] = "";
 	int err = 0;
 
-	static bool switch_aud_inprogress;
+	if (re_regex(carg->prm, str_len(carg->prm), "[^,]+,[~]*",
+		     &pl_driver, &pl_device)) {
 
-	if (!switch_aud_inprogress && !carg->complete) {
-		re_hprintf(pf,
-			   "\rPlease enter audio device (driver,device)\n");
+		return re_hprintf(pf, "\rFormat should be:"
+				  " driver,device\n");
 	}
 
-	switch_aud_inprogress = true;
+	pl_strcpy(&pl_driver, driver, sizeof(driver));
+	pl_strcpy(&pl_device, device, sizeof(device));
 
-	if (carg->complete) {
+	as = ausrc_find(baresip_ausrcl(), driver);
+	if (!as) {
+		re_hprintf(pf, "no such audio-source: %s\n", driver);
+		return 0;
+	}
+	else if (!list_isempty(&as->dev_list)) {
 
-		switch_aud_inprogress = false;
+		if (!mediadev_find(&as->dev_list, device)) {
+			re_hprintf(pf,
+				   "no such device for %s audio-source: %s\n",
+				   driver, device);
 
-		if (re_regex(carg->prm, str_len(carg->prm), "[^,]+,[~]*",
-			     &pl_driver, &pl_device)) {
+			mediadev_print(pf, &as->dev_list);
 
-			return re_hprintf(pf, "\rFormat should be:"
-					  " driver,device\n");
-		}
-
-		pl_strcpy(&pl_driver, driver, sizeof(driver));
-		pl_strcpy(&pl_device, device, sizeof(device));
-
-		as = ausrc_find(baresip_ausrcl(), driver);
-		if (!as) {
-			re_hprintf(pf, "no such audio-source: %s\n", driver);
 			return 0;
 		}
-		else if (!list_isempty(&as->dev_list)) {
+	}
 
-			if (!mediadev_find(&as->dev_list, device)) {
-				re_hprintf(pf,
-				  "no such device for %s audio-source: %s\n",
-				  driver, device);
+	re_hprintf(pf, "switch audio device: %s,%s\n",
+		   driver, device);
 
-				mediadev_print(pf, &as->dev_list);
+	cfg = conf_config();
+	if (!cfg) {
+		return re_hprintf(pf, "no config object\n");
+	}
 
-				return 0;
-			}
-		}
+	aucfg = &cfg->audio;
 
-		re_hprintf(pf, "switch audio device: %s,%s\n",
-			   driver, device);
+	str_ncpy(aucfg->src_mod, driver, sizeof(aucfg->src_mod));
+	str_ncpy(aucfg->src_dev, device, sizeof(aucfg->src_dev));
 
-		cfg = conf_config();
-		if (!cfg) {
-			return re_hprintf(pf, "no config object\n");
-		}
+	for (le = list_tail(ua_calls(uag_cur())); le; le = le->prev) {
 
-		aucfg = &cfg->audio;
+		struct call *call = le->data;
 
-		str_ncpy(aucfg->src_mod, driver, sizeof(aucfg->src_mod));
-		str_ncpy(aucfg->src_dev, device, sizeof(aucfg->src_dev));
+		a = call_audio(call);
 
-		for (le = list_tail(ua_calls(uag_cur())); le; le = le->prev) {
-
-			struct call *call = le->data;
-
-			a = call_audio(call);
-
-			err = audio_set_source(a, driver, device);
-			if (err) {
-				re_hprintf(pf, "failed to set audio-source"
-					   " (%m)\n", err);
-				break;
-			}
+		err = audio_set_source(a, driver, device);
+		if (err) {
+			re_hprintf(pf, "failed to set audio-source"
+				   " (%m)\n", err);
+			break;
 		}
 	}
 
@@ -753,72 +720,58 @@ static int switch_video_source(struct re_printf *pf, void *arg)
 	char driver[16], device[128] = "";
 	int err = 0;
 
-	static bool switch_vid_inprogress;
+	if (re_regex(carg->prm, str_len(carg->prm), "[^,]+,[~]*",
+		     &pl_driver, &pl_device)) {
 
-	if (!switch_vid_inprogress && !carg->complete) {
-		re_hprintf(pf,
-			   "\rPlease enter video device (driver,device)\n");
+		return re_hprintf(pf, "\rFormat should be:"
+				  " driver,device\n");
 	}
 
-	switch_vid_inprogress = true;
+	pl_strcpy(&pl_driver, driver, sizeof(driver));
+	pl_strcpy(&pl_device, device, sizeof(device));
 
-	if (carg->complete) {
+	vs = vidsrc_find(baresip_vidsrcl(), driver);
+	if (!vs) {
+		re_hprintf(pf, "no such video-source: %s\n", driver);
+		return 0;
+	}
+	else if (!list_isempty(&vs->dev_list)) {
 
-		switch_vid_inprogress = false;
+		if (!mediadev_find(&vs->dev_list, device)) {
+			re_hprintf(pf,
+				   "no such device for %s video-source: %s\n",
+				   driver, device);
 
-		if (re_regex(carg->prm, str_len(carg->prm), "[^,]+,[~]*",
-			     &pl_driver, &pl_device)) {
+			mediadev_print(pf, &vs->dev_list);
 
-			return re_hprintf(pf, "\rFormat should be:"
-					  " driver,device\n");
-		}
-
-		pl_strcpy(&pl_driver, driver, sizeof(driver));
-		pl_strcpy(&pl_device, device, sizeof(device));
-
-		vs = vidsrc_find(baresip_vidsrcl(), driver);
-		if (!vs) {
-			re_hprintf(pf, "no such video-source: %s\n", driver);
 			return 0;
 		}
-		else if (!list_isempty(&vs->dev_list)) {
+	}
 
-			if (!mediadev_find(&vs->dev_list, device)) {
-				re_hprintf(pf,
-				  "no such device for %s video-source: %s\n",
-				  driver, device);
+	re_hprintf(pf, "switch video device: %s,%s\n",
+		   driver, device);
 
-				mediadev_print(pf, &vs->dev_list);
+	cfg = conf_config();
+	if (!cfg) {
+		return re_hprintf(pf, "no config object\n");
+	}
 
-				return 0;
-			}
-		}
+	vidcfg = &cfg->video;
 
-		re_hprintf(pf, "switch video device: %s,%s\n",
-			   driver, device);
+	str_ncpy(vidcfg->src_mod, driver, sizeof(vidcfg->src_mod));
+	str_ncpy(vidcfg->src_dev, device, sizeof(vidcfg->src_dev));
 
-		cfg = conf_config();
-		if (!cfg) {
-			return re_hprintf(pf, "no config object\n");
-		}
+	for (le = list_tail(ua_calls(uag_cur())); le; le = le->prev) {
 
-		vidcfg = &cfg->video;
+		struct call *call = le->data;
 
-		str_ncpy(vidcfg->src_mod, driver, sizeof(vidcfg->src_mod));
-		str_ncpy(vidcfg->src_dev, device, sizeof(vidcfg->src_dev));
+		v = call_video(call);
 
-		for (le = list_tail(ua_calls(uag_cur())); le; le = le->prev) {
-
-			struct call *call = le->data;
-
-			v = call_video(call);
-
-			err = video_set_source(v, driver, device);
-			if (err) {
-				re_hprintf(pf, "failed to set video-source"
-					   " (%m)\n", err);
-				break;
-			}
+		err = video_set_source(v, driver, device);
+		if (err) {
+			re_hprintf(pf, "failed to set video-source"
+				   " (%m)\n", err);
+			break;
 		}
 	}
 
@@ -942,7 +895,7 @@ static const struct cmd callcmdv[] = {
 {"audio_debug",'A',       0, "Audio stream",        call_audio_debug      },
 {"audio_cycle",'e',       0, "Cycle audio encoder", call_audioenc_cycle   },
 {"mute",      'm',        0, "Call mute/un-mute",   call_mute             },
-{"transfer",  't', CMD_IPRM, "Transfer call",       call_xfer             },
+{"transfer",  't',  CMD_PRM, "Transfer call",       call_xfer             },
 {"hold",      'x',        0, "Call hold",           cmd_call_hold         },
 {"",          'H',        0, "Hold previous call",  hold_prev_call        },
 {"",          'L',        0, "Resume previous call",hold_prev_call        },
