@@ -24,14 +24,15 @@ struct mpa_param {
 int mpa_encode_update(struct auenc_state **aesp, const struct aucodec *ac,
 		       struct auenc_param *prm, const char *fmtp);
 int mpa_encode_frm(struct auenc_state *aes, uint8_t *buf, size_t *len,
-		    const int16_t *sampv, size_t sampc);
+		   int fmt, const void *sampv, size_t sampc);
 
 
 /* Decode */
 int mpa_decode_update(struct audec_state **adsp, const struct aucodec *ac,
 		       const char *fmtp);
-int mpa_decode_frm(struct audec_state *ads, int16_t *sampv, size_t *sampc,
-		    const uint8_t *buf, size_t len);
+int mpa_decode_frm(struct audec_state *ads,
+		   int fmt, void *sampv, size_t *sampc,
+		   const uint8_t *buf, size_t len);
 
 /* SDP */
 void mpa_decode_fmtp(struct mpa_param *prm, const char *fmtp);
