@@ -115,7 +115,7 @@ static void timestamp_state_update(struct timestamp_state *st,
 
 
 static double timestamp_state_duration(const struct timestamp_state *ts,
-				       uint32_t clock)
+				       uint32_t clock_rate)
 {
 	uint64_t dur;
 
@@ -124,7 +124,7 @@ static double timestamp_state_duration(const struct timestamp_state *ts,
 	else
 		dur = 0;
 
-	return (double)dur / (double)clock;
+	return (double)dur / (double)clock_rate;
 }
 
 
@@ -552,7 +552,7 @@ static void print_status(struct video_loop *vl)
 {
 	(void)re_fprintf(stdout,
 			 "\rstatus:"
-			 " %.3f sec [%s] [%s]  fmt=%s  intra=%zu "
+			 " %.3f sec [%s] [%s]  fmt=%s  key-frames=%zu "
 			 " EFPS=%.1f      %u kbit/s       \r",
 			 timestamp_state_duration(&vl->ts_src,
 						  VIDEO_TIMEBASE),
