@@ -21,7 +21,6 @@ enum {
 struct videnc_state {
 	vpx_codec_ctx_t ctx;
 	struct vidsz size;
-	vpx_codec_pts_t pts;
 	unsigned fps;
 	unsigned bitrate;
 	unsigned pktsize;
@@ -172,7 +171,7 @@ static inline void hdr_encode(uint8_t hdr[HDR_SIZE], bool start, bool end,
 static int send_packet(struct videnc_state *ves, bool marker,
 		       const uint8_t *hdr, size_t hdr_len,
 		       const uint8_t *pld, size_t pld_len,
-		       uint32_t rtp_ts)
+		       uint64_t rtp_ts)
 {
 	ves->n_bytes += (hdr_len + pld_len);
 
@@ -184,7 +183,7 @@ static int send_packet(struct videnc_state *ves, bool marker,
 static inline int packetize(struct videnc_state *ves,
 			    bool marker, const uint8_t *buf, size_t len,
 			    size_t maxlen, uint16_t picid,
-			    uint32_t rtp_ts)
+			    uint64_t rtp_ts)
 {
 	uint8_t hdr[HDR_SIZE];
 	bool start = true;
@@ -214,7 +213,7 @@ static inline int packetize(struct videnc_state *ves,
 
 
 int vp9_encode(struct videnc_state *ves, bool update,
-		const struct vidframe *frame)
+	       const struct vidframe *frame, uint64_t timestamp)
 {
 	vpx_enc_frame_flags_t flags = 0;
 	vpx_codec_iter_t iter = NULL;
@@ -267,7 +266,7 @@ int vp9_encode(struct videnc_state *ves, bool update,
 		img->planes[i] = frame->data[i];
 	}
 
-	res = vpx_codec_encode(&ves->ctx, img, ves->pts++, 1,
+	res = vpx_codec_encode(&ves->ctx, img, timestamp, 1,
 			       flags, VPX_DL_REALTIME);
 	if (res) {
 		warning("vp9: enc error: %s\n", vpx_codec_err_to_string(res));
@@ -280,7 +279,7 @@ int vp9_encode(struct videnc_state *ves, bool update,
 	for (;;) {
 		bool marker = true;
 		const vpx_codec_cx_pkt_t *pkt;
-		uint32_t ts;
+		uint64_t ts;
 
 		pkt = vpx_codec_get_cx_data(&ves->ctx, &iter);
 		if (!pkt)
@@ -297,7 +296,7 @@ int vp9_encode(struct videnc_state *ves, bool update,
 		if (pkt->data.frame.flags & VPX_FRAME_IS_FRAGMENT)
 			marker = false;
 
-		ts = video_calc_rtp_timestamp(pkt->data.frame.pts, ves->fps);
+		ts = video_calc_rtp_timestamp_fix(pkt->data.frame.pts);
 
 		err = packetize(ves,
 				marker,
