@@ -100,13 +100,14 @@ static inline uint8_t *x11grab_read(struct vidsrc_st *st)
 }
 
 
-static void call_frame_handler(struct vidsrc_st *st, uint8_t *buf)
+static void call_frame_handler(struct vidsrc_st *st, uint8_t *buf,
+			       uint64_t timestamp)
 {
 	struct vidframe frame;
 
 	vidframe_init_buf(&frame, st->pixfmt, &st->size, buf);
 
-	st->frameh(&frame, st->arg);
+	st->frameh(&frame, timestamp, st->arg);
 }
 
 
@@ -118,6 +119,8 @@ static void *read_thread(void *arg)
 
 	while (st->run) {
 
+		uint64_t timestamp;
+
 		if (tmr_jiffies() < ts) {
 			sys_msleep(4);
 			continue;
@@ -127,9 +130,11 @@ static void *read_thread(void *arg)
 		if (!buf)
 			continue;
 
+		timestamp = ts * VIDEO_TIMEBASE / 1000;
+
 		ts += (1000/st->fps);
 
-		call_frame_handler(st, buf);
+		call_frame_handler(st, buf, timestamp);
 	}
 
 	return NULL;
