@@ -304,7 +304,7 @@ static int sip_params_decode(struct account *acc, const struct sip_addr *aor)
 
 		char expr[16] = "outbound";
 
-		expr[8] = i + 1 + 0x30;
+		expr[8] = (char)(i + 1 + 0x30);
 		expr[9] = '\0';
 
 		err |= param_dstr(&acc->outboundv[i], &aor->params, expr);
@@ -552,6 +552,47 @@ int account_set_regint(struct account *acc, uint32_t regint)
 }
 
 
+/**
+ * Set the stun host for a SIP account
+ *
+ * @param acc   User-Agent account
+ * @param host  Stun host (NULL to reset)
+ *
+ * @return 0 if success, otherwise errorcode
+ */
+int account_set_stun_host(struct account *acc, const char *host)
+{
+	if (!acc)
+		return EINVAL;
+
+	acc->stun_host = mem_deref(acc->stun_host);
+
+	if (host)
+		return str_dup(&acc->stun_host, host);
+
+	return 0;
+}
+
+
+/**
+ * Set the port of the STUN host of a SIP account
+ *
+ * @param acc     User-Agent account
+ * @param port    Port number
+ *
+ * @return 0 if success, otherwise errorcode
+ */
+int account_set_stun_port(struct account *acc, uint16_t port)
+{
+	if (!acc)
+		return EINVAL;
+
+	acc->stun_port = port;
+
+	return 0;
+}
+
+
 /**
  * Set the media encryption for a SIP account
  *
@@ -587,6 +628,42 @@ int account_set_mediaenc(struct account *acc, const char *mencid)
 }
 
 
+/**
+ * Set the media NAT handling for a SIP account
+ *
+ * @param acc     User-Agent account
+ * @param mnatid  Media NAT handling id
+ *
+ * @return 0 if success, otherwise errorcode
+ */
+int account_set_medianat(struct account *acc, const char *mnatid)
+{
+	const struct mnat *mnat = NULL;
+
+	if (!acc)
+		return EINVAL;
+
+	if (mnatid) {
+		mnat = mnat_find(baresip_mnatl(), mnatid);
+		if (!mnat) {
+			warning("account: medianat not found: `%s'\n",
+				mnatid);
+			return EINVAL;
+		}
+	}
+
+	acc->mnatid = mem_deref(acc->mnatid);
+	acc->mnat = NULL;
+
+	if (mnatid) {
+		acc->mnat = mnat;
+		return str_dup(&acc->mnatid, mnatid);
+	}
+
+	return 0;
+}
+
+
 /**
  * Sets audio codecs
  *
@@ -806,6 +883,31 @@ enum answermode account_answermode(const struct account *acc)
 }
 
 
+/**
+ * Set the answermode of an account
+ *
+ * @param acc  User-Agent account
+ * @param mode Answermode
+ *
+ * @return 0 if success, otherwise errorcode
+ */
+int account_set_answermode(struct account *acc, enum answermode mode)
+{
+	if (!acc)
+		return EINVAL;
+
+	if ((mode != ANSWERMODE_MANUAL) && (mode != ANSWERMODE_EARLY) &&
+	    (mode != ANSWERMODE_AUTO)) {
+		warning("account: invalid answermode : `%d'\n", mode);
+		return EINVAL;
+	}
+
+	acc->answermode = mode;
+
+	return 0;
+}
+
+
 /**
  * Get the SIP Display Name of an account
  *
@@ -940,6 +1042,19 @@ const char *account_stun_host(const struct account *acc)
 }
 
 
+/**
+ * Get the port of the STUN host of an account
+ *
+ * @param acc User-Agent account
+ *
+ * @return Port number or 0 if not set
+ */
+uint16_t account_stun_port(const struct account *acc)
+{
+	return acc ? acc->stun_port : 0;
+}
+
+
 static const char *answermode_str(enum answermode mode)
 {
 	switch (mode) {
@@ -965,6 +1080,19 @@ const char *account_mediaenc(const struct account *acc)
 }
 
 
+/**
+ * Get the media NAT handling of an account
+ *
+ * @param acc User-Agent account
+ *
+ * @return Media NAT handling id or NULL if not set
+ */
+const char *account_medianat(const struct account *acc)
+{
+	return acc ? acc->mnatid : NULL;
+}
+
+
 /**
  * Get MWI capability of an account
  *
