@@ -53,7 +53,11 @@
  */
 
 enum {
-	AUDIO_SAMPSZ    = 3*1920  /* Max samples, 48000Hz 2ch at 60ms */
+	MAX_SRATE       = 48000,  /* Maximum sample rate in [Hz] */
+	MAX_CHANNELS    =     2,  /* Maximum number of channels  */
+	MAX_PTIME       =    60,  /* Maximum packet time in [ms] */
+
+	AUDIO_SAMPSZ    = MAX_SRATE * MAX_CHANNELS * MAX_PTIME / 1000,
 };
 
 
@@ -908,7 +912,6 @@ static void stream_recv_handler(const struct rtp_header *hdr,
 		return;
 
 	/* Audio payload-type changed? */
-	/* XXX: this logic should be moved to stream.c */
 	if (hdr->pt != rx->pt) {
 
 		err = update_payload_type(a, rx->pt, hdr->pt);
@@ -925,7 +928,7 @@ static void stream_recv_handler(const struct rtp_header *hdr,
 			a->rx.level_set = true;
 		}
 		else {
-			info("audio: rtp header ext ignored (id=%u)\n",
+			debug("audio: rtp header ext ignored (id=%u)\n",
 			     extv[i].id);
 		}
 	}
@@ -1119,6 +1122,28 @@ static bool ebuacip_handler(const char *name, const char *value, void *arg)
 }
 
 
+/**
+ * Allocate an audio stream
+ *
+ * @param ap         Pointer to allocated audio stream object
+ * @param stream_prm Stream parameters
+ * @param cfg        Global configuration
+ * @param call       Call object
+ * @param sdp_sess   SDP Session
+ * @param label      SDP label
+ * @param mnat       Media NAT (optional)
+ * @param mnat_sess  Media NAT session (optional)
+ * @param menc       Media Encryption (optional)
+ * @param menc_sess  Media Encryption session (optional)
+ * @param ptime      Packet time in [ms]
+ * @param aucodecl   List of audio codecs
+ * @param offerer    True if SDP offerer, false if SDP answerer
+ * @param eventh     Event handler
+ * @param errh       Error handler
+ * @param arg        Handler argument
+ *
+ * @return 0 if success, otherwise errorcode
+ */
 int audio_alloc(struct audio **ap, const struct stream_param *stream_prm,
 		const struct config *cfg,
 		struct call *call, struct sdp_session *sdp_sess, int label,
@@ -1155,7 +1180,6 @@ int audio_alloc(struct audio **ap, const struct stream_param *stream_prm,
 	err = stream_alloc(&a->strm, stream_prm, &cfg->avt, call, sdp_sess,
 			   "audio", label,
 			   mnat, mnat_sess, menc, menc_sess,
-			   call_localuri(call),
 			   stream_recv_handler, NULL, a);
 	if (err)
 		goto out;
@@ -1450,7 +1474,8 @@ static int start_player(struct aurx *rx, struct audio *a)
 		     " %uHz/%uch --> %uHz/%uch\n",
 		     get_srate(ac), get_ch(ac), srate_dsp, channels_dsp);
 
-		rx->sampv_rs = mem_zalloc(AUDIO_SAMPSZ * 2, NULL);
+		rx->sampv_rs = mem_zalloc(AUDIO_SAMPSZ * sizeof(int16_t),
+					  NULL);
 		if (!rx->sampv_rs)
 			return ENOMEM;
 
@@ -1537,7 +1562,8 @@ static int start_source(struct autx *tx, struct audio *a)
 		     " %uHz/%uch <-- %uHz/%uch\n",
 		     get_srate(ac), get_ch(ac), srate_dsp, channels_dsp);
 
-		tx->sampv_rs = mem_zalloc(AUDIO_SAMPSZ * 2, NULL);
+		tx->sampv_rs = mem_zalloc(AUDIO_SAMPSZ * sizeof(int16_t),
+					  NULL);
 		if (!tx->sampv_rs)
 			return ENOMEM;
 
@@ -1701,6 +1727,16 @@ bool audio_started(const struct audio *a)
 }
 
 
+/**
+ * Set the audio encoder used
+ *
+ * @param a      Audio object
+ * @param ac     Audio codec to use
+ * @param pt_tx  Payload type for sending
+ * @param params Optional encoder parameters
+ *
+ * @return 0 if success, otherwise errorcode
+ */
 int audio_encoder_set(struct audio *a, const struct aucodec *ac,
 		      int pt_tx, const char *params)
 {
@@ -1755,6 +1791,16 @@ int audio_encoder_set(struct audio *a, const struct aucodec *ac,
 }
 
 
+/**
+ * Set the audio decoder used
+ *
+ * @param a      Audio object
+ * @param ac     Audio codec to use
+ * @param pt_rx  Payload type for receiving
+ * @param params Optional decoder parameters
+ *
+ * @return 0 if success, otherwise errorcode
+ */
 int audio_decoder_set(struct audio *a, const struct aucodec *ac,
 		      int pt_rx, const char *params)
 {
@@ -1964,8 +2010,12 @@ void audio_sdp_attr_decode(struct audio *a)
 			tx->ptime = ptime_tx;
 
 			if (tx->ac) {
-				tx->psize = 2 * get_framesize(tx->ac,
-							      ptime_tx);
+				size_t sz;
+
+				sz = aufmt_sample_size(tx->src_fmt);
+
+				tx->psize = sz * get_framesize(tx->ac,
+							       ptime_tx);
 			}
 		}
 	}
@@ -2361,3 +2411,20 @@ void audio_set_hold(struct audio *au, bool hold)
 
 	au->hold = hold;
 }
+
+
+/**
+ * Get audio codec of audio stream
+ *
+ * @param au    Audio object
+ * @param tx    True to get transmit codec, false to get receive codec
+ *
+ * @return      Audio codec if success, otherwise NULL
+ */
+const struct aucodec *audio_codec(const struct audio *au, bool tx)
+{
+	if (!au)
+		return NULL;
+
+	return tx ? au->tx.ac : au->rx.ac;
+}
