@@ -263,7 +263,7 @@ static void mnat_handler(int err, uint16_t scode, const char *reason,
 		return;
 	}
 
-	info("call: media-nat `%s' established\n", call->acc->mnatid);
+	info("call: media-nat '%s' established\n", call->acc->mnatid);
 
 	/* Re-INVITE */
 	if (!call->mnat_wait) {
@@ -460,7 +460,7 @@ static void menc_event_handler(const enum menc_event event,
 	struct call *call = arg;
 	MAGIC_CHECK(call);
 
-	if (strlen(prm) > 0)
+	if (str_isset(prm))
 		call_event_handler(call, CALL_EVENT_MENC, "%u,%s", event,
 				   prm);
 	else
@@ -542,6 +542,8 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 
 	memset(&stream_prm, 0, sizeof(stream_prm));
 	stream_prm.use_rtp = prm->use_rtp;
+	stream_prm.af      = prm->af;
+	stream_prm.cname   = local_uri;
 
 	call = mem_zalloc(sizeof(*call), call_destructor);
 	if (!call)
@@ -559,7 +561,7 @@ int call_alloc(struct call **callp, const struct config *cfg, struct list *lst,
 	call->state  = STATE_IDLE;
 	call->eh     = eh;
 	call->arg    = arg;
-	call->af     = prm ? prm->af : AF_INET;
+	call->af     = prm->af;
 
 	err = str_dup(&call->local_uri, local_uri);
 	if (local_name)
@@ -717,6 +719,13 @@ void call_set_custom_hdrs(struct call *call, const struct list *hdrs)
 }
 
 
+/**
+ * Get the list of custom SIP headers
+ *
+ * @param call Call object
+ *
+ * @return List of custom SIP headers (struct sip_hdr)
+ */
 const struct list *call_get_custom_hdrs(const struct call *call)
 {
 	if (!call)
@@ -1194,7 +1203,7 @@ static int auth_handler(char **username, char **password,
 static int sipsess_offer_handler(struct mbuf **descp,
 				 const struct sip_msg *msg, void *arg)
 {
-	const bool got_offer = mbuf_get_left(msg->mb);
+	const bool got_offer = (0 != mbuf_get_left(msg->mb));
 	struct call *call = arg;
 	int err;
 
@@ -2025,6 +2034,12 @@ bool call_is_outgoing(const struct call *call)
 }
 
 
+/**
+ * Enable RTP timeout for a call
+ *
+ * @param call       Call object
+ * @param timeout_ms RTP Timeout in [milliseconds]
+ */
 void call_enable_rtp_timeout(struct call *call, uint32_t timeout_ms)
 {
 	if (!call)
@@ -2047,6 +2062,14 @@ uint32_t call_linenum(const struct call *call)
 }
 
 
+/**
+ * Find the call with a given line number
+ *
+ * @param calls   List of calls
+ * @param linenum Line number from 1 to N
+ *
+ * @return Call object if found, NULL if not found
+ */
 struct call *call_find_linenum(const struct list *calls, uint32_t linenum)
 {
 	struct le *le;
@@ -2062,6 +2085,12 @@ struct call *call_find_linenum(const struct list *calls, uint32_t linenum)
 }
 
 
+/**
+ * Set the current call
+ *
+ * @param calls List of calls
+ * @param call  Call to set as current
+ */
 void call_set_current(struct list *calls, struct call *call)
 {
 	if (!calls || !call)
