@@ -79,7 +79,6 @@ static struct config core_config = {
 		0xb8,
 		{1024, 49152},
 		{0, 0},
-		true,
 		false,
 		{5, 10},
 		false,
@@ -146,12 +145,10 @@ static int dns_server_handler(const struct pl *pl, void *arg)
 static enum aufmt resolve_aufmt(const struct pl *fmt)
 {
 	if (0 == pl_strcasecmp(fmt, "s16"))     return AUFMT_S16LE;
+	if (0 == pl_strcasecmp(fmt, "s16le"))   return AUFMT_S16LE;
 	if (0 == pl_strcasecmp(fmt, "float"))   return AUFMT_FLOAT;
 	if (0 == pl_strcasecmp(fmt, "s24_3le")) return AUFMT_S24_3LE;
 
-	/* XXX remove this after librem is fixed */
-	if (0 == pl_strcasecmp(fmt, "s16le"))   return AUFMT_S16LE;
-
 	return (enum aufmt)-1;
 }
 
@@ -225,6 +222,7 @@ int config_parse_conf(struct config *cfg, const struct conf *conf)
 	struct vidsz size = {0, 0};
 	struct pl txmode;
 	uint32_t v;
+	bool tmp;
 	int err = 0;
 
 	if (!cfg || !conf)
@@ -335,7 +333,13 @@ int config_parse_conf(struct config *cfg, const struct conf *conf)
 		cfg->avt.rtp_bw.min *= 1000;
 		cfg->avt.rtp_bw.max *= 1000;
 	}
-	(void)conf_get_bool(conf, "rtcp_enable", &cfg->avt.rtcp_enable);
+
+#if 1
+	if (0 == conf_get_bool(conf, "rtcp_enable", &tmp) && !tmp) {
+		warning("config: rtcp_enable ignored, always enabled\n");
+	}
+#endif
+
 	(void)conf_get_bool(conf, "rtcp_mux", &cfg->avt.rtcp_mux);
 	(void)conf_get_range(conf, "jitter_buffer_delay",
 			     &cfg->avt.jbuf_del);
@@ -416,7 +420,6 @@ int config_print(struct re_printf *pf, const struct config *cfg)
 			 "rtp_tos\t\t\t%u\n"
 			 "rtp_ports\t\t%H\n"
 			 "rtp_bandwidth\t\t%H\n"
-			 "rtcp_enable\t\t%s\n"
 			 "rtcp_mux\t\t%s\n"
 			 "jitter_buffer_delay\t%H\n"
 			 "rtp_stats\t\t%s\n"
@@ -457,7 +460,6 @@ int config_print(struct re_printf *pf, const struct config *cfg)
 			 cfg->avt.rtp_tos,
 			 range_print, &cfg->avt.rtp_ports,
 			 range_print, &cfg->avt.rtp_bw,
-			 cfg->avt.rtcp_enable ? "yes" : "no",
 			 cfg->avt.rtcp_mux ? "yes" : "no",
 			 range_print, &cfg->avt.jbuf_del,
 			 cfg->avt.rtp_stats ? "yes" : "no",
@@ -576,7 +578,7 @@ static int core_config_template(struct re_printf *pf, const struct config *cfg)
 			  "#ausrc_srate\t\t48000\n"
 			  "#auplay_srate\t\t48000\n"
 			  "#ausrc_channels\t\t0\n"
-			  "#auplay_channels\t\t0\n"
+			  "#auplay_channels\t0\n"
 			  "#audio_txmode\t\tpoll\t\t# poll, thread\n"
 			  "audio_level\t\tno\n"
 			  "ausrc_format\t\ts16\t\t# s16, float, ..\n"
@@ -614,7 +616,6 @@ static int core_config_template(struct re_printf *pf, const struct config *cfg)
 			  "rtp_tos\t\t\t184\n"
 			  "#rtp_ports\t\t10000-20000\n"
 			  "#rtp_bandwidth\t\t512-1024 # [kbit/s]\n"
-			  "rtcp_enable\t\tyes\n"
 			  "rtcp_mux\t\tno\n"
 			  "jitter_buffer_delay\t%u-%u\t\t# frames\n"
 			  "rtp_stats\t\tno\n"
@@ -756,7 +757,6 @@ int config_write_template(const char *file, const struct config *cfg)
 
 	(void)re_fprintf(f, "\n# Audio codec Modules (in order)\n");
 	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "opus" MOD_EXT "\n");
-	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "silk" MOD_EXT "\n");
 	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "amr" MOD_EXT "\n");
 	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "g7221" MOD_EXT "\n");
 	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "g722" MOD_EXT "\n");
@@ -842,7 +842,7 @@ int config_write_template(const char *file, const struct config *cfg)
 
 	(void)re_fprintf(f, "\n# Video display modules\n");
 #ifdef DARWIN
-	(void)re_fprintf(f, "module\t\t\t" MOD_PRE "opengl" MOD_EXT "\n");
+	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "opengl" MOD_EXT "\n");
 #endif
 #ifdef LINUX
 	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "directfb" MOD_EXT "\n");
@@ -863,6 +863,7 @@ int config_write_template(const char *file, const struct config *cfg)
 	(void)re_fprintf(f, "module\t\t\t" MOD_PRE "turn" MOD_EXT "\n");
 	(void)re_fprintf(f, "module\t\t\t" MOD_PRE "ice" MOD_EXT "\n");
 	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "natpmp" MOD_EXT "\n");
+	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "pcp" MOD_EXT "\n");
 
 	(void)re_fprintf(f, "\n# Media encryption modules\n");
 	(void)re_fprintf(f, "#module\t\t\t" MOD_PRE "srtp" MOD_EXT "\n");
@@ -931,6 +932,9 @@ int config_write_template(const char *file, const struct config *cfg)
 	(void)re_fprintf(f, "#opus_complexity\t\t10\n");
 	(void)re_fprintf(f, "#opus_application\t\taudio\t# {voip,audio}\n");
 
+	(void)re_fprintf(f, "\n");
+	(void)re_fprintf(f, "vumeter_stderr\t\tyes\n");
+
 	(void)re_fprintf(f,
 			"\n# Selfview\n"
 			"video_selfview\t\twindow # {window,pip}\n"
