@@ -107,20 +107,6 @@ struct ausrc_st {
 
 struct audio;
 
-typedef void (audio_event_h)(int key, bool end, void *arg);
-typedef void (audio_err_h)(int err, const char *str, void *arg);
-
-int audio_alloc(struct audio **ap, const struct stream_param *stream_prm,
-		const struct config *cfg,
-		struct call *call, struct sdp_session *sdp_sess, int label,
-		const struct mnat *mnat, struct mnat_sess *mnat_sess,
-		const struct menc *menc, struct menc_sess *menc_sess,
-		uint32_t ptime, const struct list *aucodecl, bool offerer,
-		audio_event_h *eventh, audio_err_h *errh, void *arg);
-int  audio_encoder_set(struct audio *a, const struct aucodec *ac,
-		       int pt_tx, const char *params);
-int  audio_decoder_set(struct audio *a, const struct aucodec *ac,
-		       int pt_rx, const char *params);
 int  audio_send_digit(struct audio *a, char key);
 void audio_sdp_attr_decode(struct audio *a);
 int  audio_print_rtpstat(struct re_printf *pf, const struct audio *au);
@@ -250,7 +236,6 @@ double   metric_avg_bitrate(const struct metric *metric);
  */
 
 int module_init(const struct conf *conf);
-void module_app_unload(void);
 
 
 /*
@@ -321,11 +306,6 @@ typedef void (stream_rtcp_h)(struct rtcp_msg *msg, void *arg);
 
 typedef void (stream_error_h)(struct stream *strm, int err, void *arg);
 
-/** Common parameters for media stream */
-struct stream_param {
-	bool use_rtp;
-};
-
 /** Defines a generic media stream */
 struct stream {
 #ifndef RELEASE
@@ -348,20 +328,19 @@ struct stream {
 	uint32_t ssrc_rx;        /**< Incoming syncronizing source          */
 	uint32_t pseq;           /**< Sequence number for incoming RTP      */
 	int pt_enc;              /**< Payload type for encoding             */
-	bool rtcp;               /**< Enable RTCP                           */
 	bool rtcp_mux;           /**< RTP/RTCP multiplex supported by peer  */
 	bool jbuf_started;       /**< True if jitter-buffer was started     */
-	stream_rtp_h *rtph;      /**< Stream RTP handler                    */
-	stream_rtcp_h *rtcph;    /**< Stream RTCP handler                   */
-	void *arg;               /**< Handler argument                      */
-	stream_error_h *errorh;  /**< Stream error handler                  */
-	void *errorh_arg;        /**< Error handler argument                */
 	struct tmr tmr_rtp;      /**< Timer for detecting RTP timeout       */
 	uint64_t ts_last;        /**< Timestamp of last received RTP pkt    */
 	bool terminated;         /**< Stream is terminated flag             */
 	uint32_t rtp_timeout_ms; /**< RTP Timeout value in [ms]             */
 	bool rtp_estab;          /**< True if RTP stream is established     */
 	bool hold;               /**< Stream is on-hold (local)             */
+	stream_rtp_h *rtph;      /**< Stream RTP handler                    */
+	stream_rtcp_h *rtcph;    /**< Stream RTCP handler                   */
+	void *arg;               /**< Handler argument                      */
+	stream_error_h *errorh;  /**< Stream error handler                  */
+	void *errorh_arg;        /**< Error handler argument                */
 };
 
 int  stream_alloc(struct stream **sp, const struct stream_param *prm,
@@ -370,12 +349,9 @@ int  stream_alloc(struct stream **sp, const struct stream_param *prm,
 		  const char *name, int label,
 		  const struct mnat *mnat, struct mnat_sess *mnat_sess,
 		  const struct menc *menc, struct menc_sess *menc_sess,
-		  const char *cname,
 		  stream_rtp_h *rtph, stream_rtcp_h *rtcph, void *arg);
-struct sdp_media *stream_sdpmedia(const struct stream *s);
 int  stream_send(struct stream *s, bool ext, bool marker, int pt, uint32_t ts,
 		 struct mbuf *mb);
-void stream_update(struct stream *s);
 void stream_update_encoder(struct stream *s, int pt_enc);
 int  stream_jbuf_stat(struct re_printf *pf, const struct stream *s);
 void stream_hold(struct stream *s, bool hold);
