@@ -85,7 +85,7 @@ int main(int argc, char *argv[])
 	setbuf(stdout, NULL);
 
 	(void)re_fprintf(stdout, "baresip v%s"
-			 " Copyright (C) 2010 - 2018"
+			 " Copyright (C) 2010 - 2019"
 			 " Alfred E. Heggestad et al.\n",
 			 BARESIP_VERSION);
 
@@ -97,7 +97,7 @@ int main(int argc, char *argv[])
 
 #ifdef HAVE_GETOPT
 	for (;;) {
-		const int c = getopt(argc, argv, "6de:f:p:hun:vtm:");
+		const int c = getopt(argc, argv, "6de:f:p:hu:n:vtm:");
 		if (0 > c)
 			break;
 
@@ -266,6 +266,10 @@ int main(int argc, char *argv[])
 		ua_stop_all(true);
 
 	ua_close();
+
+	/* note: must be done before mod_close() */
+	module_app_unload();
+
 	conf_close();
 
 	baresip_close();
