@@ -331,7 +331,7 @@ static int stream_sock_alloc(struct stream *s, int af)
 
 	err = rtp_listen(&s->rtp, IPPROTO_UDP, &laddr,
 			 s->cfg.rtp_ports.min, s->cfg.rtp_ports.max,
-			 s->rtcp, rtp_handler, rtcp_handler, s);
+			 true, rtp_handler, rtcp_handler, s);
 	if (err) {
 		warning("stream: rtp_listen failed: af=%s ports=%u-%u"
 			" (%m)\n", net_af2name(af),
@@ -359,13 +359,12 @@ int stream_alloc(struct stream **sp, const struct stream_param *prm,
 		 const char *name, int label,
 		 const struct mnat *mnat, struct mnat_sess *mnat_sess,
 		 const struct menc *menc, struct menc_sess *menc_sess,
-		 const char *cname,
 		 stream_rtp_h *rtph, stream_rtcp_h *rtcph, void *arg)
 {
 	struct stream *s;
 	int err;
 
-	if (!sp || !prm || !cfg || !call || !rtph)
+	if (!sp || !prm || !cfg || !rtph)
 		return EINVAL;
 
 	s = mem_zalloc(sizeof(*s), stream_destructor);
@@ -380,10 +379,9 @@ int stream_alloc(struct stream **sp, const struct stream_param *prm,
 	s->rtcph = rtcph;
 	s->arg   = arg;
 	s->pseq  = -1;
-	s->rtcp  = s->cfg.rtcp_enable;
 
 	if (prm->use_rtp) {
-		err = stream_sock_alloc(s, call_af(call));
+		err = stream_sock_alloc(s, prm->af);
 		if (err) {
 			warning("stream: failed to create socket"
 				" for media '%s' (%m)\n", name, err);
@@ -391,7 +389,7 @@ int stream_alloc(struct stream **sp, const struct stream_param *prm,
 		}
 	}
 
-	err = str_dup(&s->cname, cname);
+	err = str_dup(&s->cname, prm->cname);
 	if (err)
 		goto out;
 
@@ -417,15 +415,12 @@ int stream_alloc(struct stream **sp, const struct stream_param *prm,
 	}
 
 	/* RFC 5506 */
-	if (s->rtcp)
-		err |= sdp_media_set_lattr(s->sdp, true, "rtcp-rsize", NULL);
+	err |= sdp_media_set_lattr(s->sdp, true, "rtcp-rsize", NULL);
 
 	/* RFC 5576 */
-	if (s->rtcp) {
-		err |= sdp_media_set_lattr(s->sdp, true,
-					   "ssrc", "%u cname:%s",
-					   rtp_sess_ssrc(s->rtp), cname);
-	}
+	err |= sdp_media_set_lattr(s->sdp, true,
+				   "ssrc", "%u cname:%s",
+				   rtp_sess_ssrc(s->rtp), prm->cname);
 
 	/* RFC 5761 */
 	if (cfg->rtcp_mux)
@@ -437,7 +432,7 @@ int stream_alloc(struct stream **sp, const struct stream_param *prm,
 	if (mnat && s->rtp) {
 		err = mnat->mediah(&s->mns, mnat_sess, IPPROTO_UDP,
 				   rtp_sock(s->rtp),
-				   s->rtcp ? rtcp_sock(s->rtp) : NULL,
+				   rtcp_sock(s->rtp),
 				   s->sdp);
 		if (err)
 			goto out;
@@ -450,7 +445,7 @@ int stream_alloc(struct stream **sp, const struct stream_param *prm,
 				   s->rtp,
 				   IPPROTO_UDP,
 				   rtp_sock(s->rtp),
-				   s->rtcp ? rtcp_sock(s->rtp) : NULL,
+				   rtcp_sock(s->rtp),
 				   s->sdp);
 		if (err)
 			goto out;
@@ -476,9 +471,16 @@ int stream_alloc(struct stream **sp, const struct stream_param *prm,
 }
 
 
-struct sdp_media *stream_sdpmedia(const struct stream *s)
+/**
+ * Get the sdp object from the stream
+ *
+ * @param strm Stream object
+ *
+ * @return SDP media object
+ */
+struct sdp_media *stream_sdpmedia(const struct stream *strm)
 {
-	return s ? s->sdp : NULL;
+	return strm ? strm->sdp : NULL;
 }
 
 
@@ -538,6 +540,11 @@ static void stream_remote_set(struct stream *s)
 }
 
 
+/**
+ * Update the media stream
+ *
+ * @param s Stream object
+ */
 void stream_update(struct stream *s)
 {
 	const struct sdp_format *fmt;
@@ -557,7 +564,7 @@ void stream_update(struct stream *s)
 		err = s->menc->mediah(&s->mes, s->mencs, s->rtp,
 				      IPPROTO_UDP,
 				      rtp_sock(s->rtp),
-				      s->rtcp ? rtcp_sock(s->rtp) : NULL,
+				      rtcp_sock(s->rtp),
 				      s->sdp);
 		if (err) {
 			warning("stream: mediaenc update: %m\n", err);
@@ -751,48 +758,77 @@ struct call *stream_call(const struct stream *strm)
 
 
 /**
- * Get the sdp object from the stream
+ * Get the number of transmitted RTP packets
  *
  * @param strm Stream object
  *
- * @return SDP media object
+ * @return Number of transmitted RTP packets
  */
-const struct sdp_media *stream_sdp(const struct stream *strm)
-{
-	return strm ? strm->sdp : NULL;
-}
-
-
 uint32_t stream_metric_get_tx_n_packets(const struct stream *strm)
 {
 	return strm ? strm->metric_tx.n_packets : 0;
 }
 
 
+/**
+ * Get the number of transmitted RTP bytes
+ *
+ * @param strm Stream object
+ *
+ * @return Number of transmitted RTP bytes
+ */
 uint32_t stream_metric_get_tx_n_bytes(const struct stream *strm)
 {
 	return strm ? strm->metric_tx.n_bytes : 0;
 }
 
 
+/**
+ * Get the number of transmission errors
+ *
+ * @param strm Stream object
+ *
+ * @return Number of transmission errors
+ */
 uint32_t stream_metric_get_tx_n_err(const struct stream *strm)
 {
 	return strm ? strm->metric_tx.n_err : 0;
 }
 
 
+/**
+ * Get the number of received RTP packets
+ *
+ * @param strm Stream object
+ *
+ * @return Number of received RTP packets
+ */
 uint32_t stream_metric_get_rx_n_packets(const struct stream *strm)
 {
 	return strm ? strm->metric_rx.n_packets : 0;
 }
 
 
+/**
+ * Get the number of received RTP bytes
+ *
+ * @param strm Stream object
+ *
+ * @return Number of received RTP bytes
+ */
 uint32_t stream_metric_get_rx_n_bytes(const struct stream *strm)
 {
 	return strm ? strm->metric_rx.n_bytes : 0;
 }
 
 
+/**
+ * Get the number of receive errors
+ *
+ * @param strm Stream object
+ *
+ * @return Number of receive errors
+ */
 uint32_t stream_metric_get_rx_n_err(const struct stream *strm)
 {
 	return strm ? strm->metric_rx.n_err : 0;
