@@ -41,6 +41,18 @@ int timestamp_wrap(uint32_t ts_new, uint32_t ts_old)
 }
 
 
+void timestamp_set(struct timestamp_recv *ts, uint32_t rtp_ts)
+{
+	if (!ts)
+		return;
+
+	ts->first = rtp_ts;
+	ts->last  = rtp_ts;
+
+	ts->is_set = true;
+}
+
+
 /**
  * Calculate the total timestamp duration, in timestamp units.
  * The duration is calculated as the delta between the
@@ -57,9 +69,18 @@ uint64_t timestamp_duration(const struct timestamp_recv *ts)
 	if (!ts || !ts->is_set)
 		return 0;
 
-	last_ext = calc_extended_timestamp(ts->num_wraps, ts->last);
+	last_ext = timestamp_calc_extended(ts->num_wraps, ts->last);
 
 	return last_ext - ts->first;
 }
 
 
+uint64_t timestamp_calc_extended(uint32_t num_wraps, uint32_t ts)
+{
+	uint64_t ext_ts;
+
+	ext_ts  = (uint64_t)num_wraps * 0x100000000ULL;
+	ext_ts += (uint64_t)ts;
+
+	return ext_ts;
+}
