@@ -397,8 +397,21 @@ static void call_dtmf_handler(struct call *call, char key, void *arg)
 }
 
 
+/**
+ * Create a new call object
+ *
+ * @param callp     Pointer to allocated call object
+ * @param ua        User-agent
+ * @param vmode     Wanted video mode
+ * @param msg       SIP message for incoming calls
+ * @param xcall     Optional call to inherit properties from
+ * @param local_uri Local SIP uri
+ * @param use_rtp   Use RTP flag
+ *
+ * @return 0 if success, otherwise errorcode
+ */
 int ua_call_alloc(struct call **callp, struct ua *ua,
-		  enum vidmode vidmode, const struct sip_msg *msg,
+		  enum vidmode vmode, const struct sip_msg *msg,
 		  struct call *xcall, const char *local_uri,
 		  bool use_rtp)
 {
@@ -423,7 +436,7 @@ int ua_call_alloc(struct call **callp, struct ua *ua,
 	memset(&cprm, 0, sizeof(cprm));
 
 	sa_cpy(&cprm.laddr, net_laddr_af(net, af));
-	cprm.vidmode = vidmode;
+	cprm.vidmode = vmode;
 	cprm.af      = af;
 	cprm.use_rtp = use_rtp;
 
@@ -712,6 +725,15 @@ int ua_update_account(struct ua *ua)
 }
 
 
+/**
+ * Auto complete a SIP uri, add scheme and domain if missing
+ *
+ * @param ua  User-Agent
+ * @param buf Target buffer to print SIP uri
+ * @param uri Input SIP uri
+ *
+ * @return 0 if success, otherwise errorcode
+ */
 int ua_uri_complete(struct ua *ua, struct mbuf *buf, const char *uri)
 {
 	struct account *acc;
@@ -1091,6 +1113,13 @@ struct call *ua_call(const struct ua *ua)
 }
 
 
+/**
+ * Get the previous call
+ *
+ * @param ua User-Agent
+ *
+ * @return Previous call or NULL if none
+ */
 struct call *ua_prev_call(const struct ua *ua)
 {
 	struct le *le;
@@ -1375,6 +1404,14 @@ static void ua_xhdr_filter_destructor(void *arg)
 }
 
 
+/**
+ * Add custom SIP header to filter for incoming calls
+ *
+ * @param ua       User-Agent
+ * @param hdr_name SIP Header name
+ *
+ * @return 0 if success, otherwise errorcode
+ */
 int ua_add_xhdr_filter(struct ua *ua, const char *hdr_name)
 {
 	struct ua_xhdr_filter *filter;
@@ -1383,12 +1420,10 @@ int ua_add_xhdr_filter(struct ua *ua, const char *hdr_name)
 		return EINVAL;
 
 	filter = mem_zalloc(sizeof(*filter), ua_xhdr_filter_destructor);
-	if (!filter) {
+	if (!filter)
 		return ENOMEM;
-	}
 
-	if (str_dup(&filter->hdr_name, hdr_name))
-	{
+	if (str_dup(&filter->hdr_name, hdr_name)) {
 		mem_deref(filter);
 		return ENOMEM;
 	}
@@ -1517,9 +1552,6 @@ void ua_close(void)
 
 	list_flush(&uag.ual);
 	list_flush(&uag.ehl);
-
-	/* note: must be done before mod_close() */
-	module_app_unload();
 }
 
 
@@ -1554,13 +1586,9 @@ void ua_stop_all(bool forced)
 	}
 
 	if (ext_ref) {
-		info("ua: in use (%u) by app module"
-		     ", deferring module unloading\n", ext_ref);
+		info("ua: in use (%u) by app module\n", ext_ref);
 		return;
 	}
-	else {
-		module_app_unload();
-	}
 
 	if (forced)
 		sipsess_close_all(uag.sock);
@@ -2107,21 +2135,37 @@ int uag_set_extra_params(const char *eprm)
 }
 
 
-void ua_set_custom_hdrs(struct ua *ua, struct list *custom_headers)
+/**
+ * Set a list of custom SIP headers
+ *
+ * @param ua             User-Agent
+ * @param custom_headers List of custom SIP headers (struct sip_hdr)
+ *
+ * @return 0 if success, otherwise errorcode
+ */
+int ua_set_custom_hdrs(struct ua *ua, struct list *custom_headers)
 {
 	struct le *le;
+	int err;
 
 	if (!ua)
-		return;
+		return EINVAL;
 
 	list_flush(&ua->custom_hdrs);
 
 	LIST_FOREACH(custom_headers, le) {
 		struct sip_hdr *hdr = le->data;
-		char *buf = NULL;
+		char *buf;
 
-		re_sdprintf(&buf, "%r", &hdr->name);
-		custom_hdrs_add(&ua->custom_hdrs, buf, "%r", &hdr->val);
+		err = pl_strdup(&buf, &hdr->name);
+		if (err)
+			return err;
+
+		err = custom_hdrs_add(&ua->custom_hdrs, buf, "%r", &hdr->val);
 		mem_deref(buf);
+		if (err)
+			return err;
 	}
+
+	return 0;
 }
