@@ -251,7 +251,7 @@ static void vidqueue_poll(struct vtx *vtx, uint64_t jfs, uint64_t prev_jfs)
 	 * time [ms] * bitrate [kbps] / 8 = bytes
 	 */
 	bandwidth_kbps = vtx->video->cfg.bitrate / 1000;
-	burst = (1 + jfs - prev_jfs) * bandwidth_kbps / 4;
+	burst = (size_t)((1 + jfs - prev_jfs) * bandwidth_kbps / 4);
 
 	burst = min(burst, BURST_MAX);
 	sent  = 0;
@@ -559,8 +559,6 @@ static void request_picture_update(struct vrx *vrx)
 	/* send RTCP FIR to peer */
 	stream_send_fir(v->strm, v->nack_pli);
 
-	/* XXX: if RTCP is not enabled, send XML in SIP INFO ? */
-
 	++vrx->n_picup;
 }
 
@@ -872,7 +870,6 @@ int video_alloc(struct video **vp, const struct stream_param *stream_prm,
 	err = stream_alloc(&v->strm, stream_prm,
 			   &cfg->avt, call, sdp_sess, "video", label,
 			   mnat, mnat_sess, menc, menc_sess,
-			   call_localuri(call),
 			   stream_recv_handler, rtcp_handler, v);
 	if (err)
 		goto out;
@@ -949,8 +946,6 @@ static void vidisp_resize_handler(const struct vidsz *sz, void *arg)
 	MAGIC_CHECK(vrx->video);
 
 	info("video: display resized: %u x %u\n", sz->w, sz->h);
-
-	/* XXX: update wanted picturesize and send re-invite to peer */
 }
 
 
@@ -1417,7 +1412,7 @@ static int vrx_debug(struct re_printf *pf, const struct vrx *vrx)
 			  vrx->vidisp ? vidisp_get(vrx->vidisp)->name : "none",
 			  vrx->size.w, vrx->size.h,
 			  vrx->stats.disp_frames);
-	err |= re_hprintf(pf, "     n_intra=%u, n_picup=%u\n",
+	err |= re_hprintf(pf, "     n_keyframes=%u, n_picup=%u\n",
 			  vrx->n_intra, vrx->n_picup);
 
 	if (vrx->ts_recv.is_set) {
