@@ -915,12 +915,15 @@ int test_call_progress(void)
 }
 
 
-static void float_sample_handler(const void *sampv, size_t sampc, void *arg)
+static void audio_sample_handler(const void *sampv, size_t sampc, void *arg)
 {
 	struct fixture *fix = arg;
+	int err = 0;
 	(void)sampv;
 	(void)sampc;
 
+	ASSERT_EQ(MAGIC, fix->magic);
+
 	/* Wait until the call is established and the incoming
 	 * audio samples are successfully decoded.
 	 */
@@ -930,6 +933,10 @@ static void float_sample_handler(const void *sampv, size_t sampc, void *arg)
 	    ) {
 		re_cancel();
 	}
+
+ out:
+	if (err)
+		fixture_abort(fix, err);
 }
 
 
@@ -949,7 +956,7 @@ static int test_media_base(enum audio_mode txmode)
 
 	err = mock_ausrc_register(&ausrc);
 	TEST_ERR(err);
-	err = mock_auplay_register(&auplay, float_sample_handler, f);
+	err = mock_auplay_register(&auplay, audio_sample_handler, f);
 	TEST_ERR(err);
 
 	f->estab_action = ACTION_NOTHING;
@@ -1024,7 +1031,7 @@ int test_call_mediaenc(void)
 
 	err = mock_ausrc_register(&ausrc);
 	TEST_ERR(err);
-	err = mock_auplay_register(&auplay, float_sample_handler, f);
+	err = mock_auplay_register(&auplay, audio_sample_handler, f);
 	TEST_ERR(err);
 
 	f->estab_action = ACTION_NOTHING;
@@ -1064,6 +1071,59 @@ int test_call_mediaenc(void)
 }
 
 
+int test_call_medianat(void)
+{
+	struct fixture fix, *f = &fix;
+	struct ausrc *ausrc = NULL;
+	struct auplay *auplay = NULL;
+	int err;
+
+	err = mock_mnat_register(baresip_mnatl());
+	ASSERT_EQ(0, err);
+
+	/* Enable a dummy media NAT-traversal protocol */
+	fixture_init_prm(f, ";medianat=XNAT;ptime=1");
+
+	ASSERT_STREQ("XNAT", account_medianat(ua_account(f->a.ua)));
+
+	err = mock_ausrc_register(&ausrc);
+	TEST_ERR(err);
+	err = mock_auplay_register(&auplay, audio_sample_handler, f);
+	TEST_ERR(err);
+
+	f->estab_action = ACTION_NOTHING;
+
+	f->behaviour = BEHAVIOUR_ANSWER;
+
+	/* Make a call from A to B */
+	err = ua_connect(f->a.ua, 0, NULL, f->buri, VIDMODE_OFF);
+	TEST_ERR(err);
+
+	/* run main-loop with timeout, wait for events */
+	err = re_main_timeout(5000);
+	TEST_ERR(err);
+	TEST_ERR(fix.err);
+
+	ASSERT_EQ(1, fix.a.n_established);
+	ASSERT_EQ(0, fix.a.n_closed);
+
+	ASSERT_EQ(1, fix.b.n_established);
+	ASSERT_EQ(0, fix.b.n_closed);
+
+ out:
+	fixture_close(f);
+	mem_deref(auplay);
+	mem_deref(ausrc);
+
+	mock_mnat_unregister();
+
+	if (fix.err)
+		return fix.err;
+
+	return err;
+}
+
+
 int test_call_custom_headers(void)
 {
 	struct fixture fix, *f = &fix;
@@ -1083,10 +1143,15 @@ int test_call_custom_headers(void)
 	 * with some custom headers in INVITE message */
 
 	list_init(&custom_hdrs);
-	err = custom_hdrs_add(&custom_hdrs, "X-CALL_ID", "%d", some_id);
-	err = custom_hdrs_add(&custom_hdrs, "X-HEADER_NAME", "%s", "VALUE");
-	ua_set_custom_hdrs(f->a.ua, &custom_hdrs);
+	err  = custom_hdrs_add(&custom_hdrs, "X-CALL_ID", "%d", some_id);
+	err |= custom_hdrs_add(&custom_hdrs, "X-HEADER_NAME", "%s", "VALUE");
+	TEST_ERR(err);
+
+	err = ua_set_custom_hdrs(f->a.ua, &custom_hdrs);
+	TEST_ERR(err);
+
 	err = ua_connect(f->a.ua, 0, NULL, f->buri, VIDMODE_OFF);
+	TEST_ERR(err);
 
 	list_flush(&custom_hdrs);
 	TEST_ERR(err);
